@@ -11,6 +11,16 @@ class InvalidSignatureError(PolySwarmTransactionException):
 
 
 class WrongSignatureError(PolySwarmTransactionException):
+    """
+    To be raised when the payload signature does not match
+    """
+    pass
+
+
+class WrongPayloadError(PolySwarmTransactionException):
+    """
+    To be raised when the signed payload does not comply with the transaction payload needed
+    """
     pass
 
 
